==> jc-1.4.0.tar.gz: java/text/AttributedString__24AttributeRange.h <==
// final class java.text.AttributedString$AttributeRange

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 44a18399858931db java_text_AttributedString__24AttributeRange

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_text_AttributedString__24AttributeRange_H_
#define _JC_java_text_AttributedString__24AttributeRange_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_text_AttributedString$object;
struct _jc_java_util_Map$object;

// Typedefs
typedef struct _jc_java_text_AttributedString__24AttributeRange$sub_refs	_jc_java_text_AttributedString__24AttributeRange$sub_refs;
typedef struct _jc_java_text_AttributedString__24AttributeRange$sub_nonrefs	_jc_java_text_AttributedString__24AttributeRange$sub_nonrefs;
typedef struct _jc_java_text_AttributedString__24AttributeRange$refs	_jc_java_text_AttributedString__24AttributeRange$refs;
typedef struct _jc_java_text_AttributedString__24AttributeRange$nonrefs	_jc_java_text_AttributedString__24AttributeRange$nonrefs;
typedef struct _jc_java_text_AttributedString__24AttributeRange$object	_jc_java_text_AttributedString__24AttributeRange$object;

typedef const struct _jc_java_text_AttributedString__24AttributeRange$vmethods	_jc_java_text_AttributedString__24AttributeRange$vmethods;
typedef const struct _jc_java_text_AttributedString__24AttributeRange$vtable	_jc_java_text_AttributedString__24AttributeRange$vtable;
typedef const struct _jc_java_text_AttributedString__24AttributeRange$vtype	_jc_java_text_AttributedString__24AttributeRange$vtype;

// Constructors
extern void _jc_java_text_AttributedString__24AttributeRange$method$_init$bf737279e091c24f(_jc_env *, struct _jc_java_text_AttributedString__24AttributeRange$object *, struct _jc_java_text_AttributedString$object *, struct _jc_object *, jint, jint);

// Virtual methods structure
struct _jc_java_text_AttributedString__24AttributeRange$vmethods {
};

// Vtable
struct _jc_java_text_AttributedString__24AttributeRange$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_text_AttributedString__24AttributeRange$vmethods	java_text_AttributedString__24AttributeRange;
};

// Vtype
struct _jc_java_text_AttributedString__24AttributeRange$vtype {
	_jc_type			type;
	_jc_java_text_AttributedString__24AttributeRange$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_text_AttributedString__24AttributeRange$sub_refs {
	struct _jc_object	*attribs;
	struct _jc_java_text_AttributedString$object	*this;
};

// Reference instance fields (object)
struct _jc_java_text_AttributedString__24AttributeRange$refs {
    _jc_java_text_AttributedString__24AttributeRange$sub_refs	java_text_AttributedString__24AttributeRange;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_text_AttributedString__24AttributeRange$sub_nonrefs {
	jint	begin__5findex;
	jint	end__5findex;
};

// Non-reference instance fields (object)
struct _jc_java_text_AttributedString__24AttributeRange$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_text_AttributedString__24AttributeRange$sub_nonrefs	java_text_AttributedString__24AttributeRange;
};

// Object instance structure
struct _jc_java_text_AttributedString__24AttributeRange$object {
	_jc_java_text_AttributedString__24AttributeRange$refs	refs[0];
	_jc_word		lockword;
	_jc_java_text_AttributedString__24AttributeRange$vtype	*vtype;
	_jc_java_text_AttributedString__24AttributeRange$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_text_AttributedString__24AttributeRange$vtype _jc_java_text_AttributedString__24AttributeRange$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_text_AttributedString__24AttributeRange, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_text_AttributedString__24AttributeRange$class_object;

#endif	/* _JC_java_text_AttributedString__24AttributeRange_H_ */

==> jc-1.4.6.tar.gz: java/text/AttributedString__24AttributeRange.h <==
// final class java.text.AttributedString$AttributeRange

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 44a18399858931db java_text_AttributedString__24AttributeRange

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_text_AttributedString__24AttributeRange_H_
#define _JC_java_text_AttributedString__24AttributeRange_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_text_AttributedString$object;
struct _jc_java_util_Map$object;

// Typedefs
typedef struct _jc_java_text_AttributedString__24AttributeRange$sub_refs	_jc_java_text_AttributedString__24AttributeRange$sub_refs;
typedef struct _jc_java_text_AttributedString__24AttributeRange$sub_nonrefs	_jc_java_text_AttributedString__24AttributeRange$sub_nonrefs;
typedef struct _jc_java_text_AttributedString__24AttributeRange$refs	_jc_java_text_AttributedString__24AttributeRange$refs;
typedef struct _jc_java_text_AttributedString__24AttributeRange$nonrefs	_jc_java_text_AttributedString__24AttributeRange$nonrefs;
typedef struct _jc_java_text_AttributedString__24AttributeRange$object	_jc_java_text_AttributedString__24AttributeRange$object;

typedef const struct _jc_java_text_AttributedString__24AttributeRange$vmethods	_jc_java_text_AttributedString__24AttributeRange$vmethods;
typedef const struct _jc_java_text_AttributedString__24AttributeRange$vtable	_jc_java_text_AttributedString__24AttributeRange$vtable;
typedef const struct _jc_java_text_AttributedString__24AttributeRange$vtype	_jc_java_text_AttributedString__24AttributeRange$vtype;

// Constructors
extern void _jc_java_text_AttributedString__24AttributeRange$method$_init$bf737279e091c24f(_jc_env *, struct _jc_java_text_AttributedString__24AttributeRange$object *, struct _jc_java_text_AttributedString$object *, struct _jc_object *, jint, jint) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_text_AttributedString__24AttributeRange$vmethods {
};

// Vtable
struct _jc_java_text_AttributedString__24AttributeRange$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_text_AttributedString__24AttributeRange$vmethods	java_text_AttributedString__24AttributeRange;
};

// Vtype
struct _jc_java_text_AttributedString__24AttributeRange$vtype {
	_jc_type			type;
	_jc_java_text_AttributedString__24AttributeRange$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_text_AttributedString__24AttributeRange$sub_refs {
	struct _jc_object	*attribs;
	struct _jc_java_text_AttributedString$object	*this;
};

// Reference instance fields (object)
struct _jc_java_text_AttributedString__24AttributeRange$refs {
    _jc_java_text_AttributedString__24AttributeRange$sub_refs	java_text_AttributedString__24AttributeRange;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_text_AttributedString__24AttributeRange$sub_nonrefs {
	jint	begin__5findex;
	jint	end__5findex;
};

// Non-reference instance fields (object)
struct _jc_java_text_AttributedString__24AttributeRange$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_text_AttributedString__24AttributeRange$sub_nonrefs	java_text_AttributedString__24AttributeRange;
};

// Object instance structure
struct _jc_java_text_AttributedString__24AttributeRange$object {
	_jc_java_text_AttributedString__24AttributeRange$refs	refs[0];
	_jc_word		lockword;
	_jc_java_text_AttributedString__24AttributeRange$vtype	*vtype;
	_jc_java_text_AttributedString__24AttributeRange$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_text_AttributedString__24AttributeRange$vtype _jc_java_text_AttributedString__24AttributeRange$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_text_AttributedString__24AttributeRange, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_text_AttributedString__24AttributeRange$class_object;

#endif	/* _JC_java_text_AttributedString__24AttributeRange_H_ */
